pub struct RemoteAgentClientConfiguration { /* private fields */ }Expand description
Datadog Agent IPC client configuration.
Implementations
Sourceimpl RemoteAgentClientConfiguration
impl RemoteAgentClientConfiguration
Sourcepub fn from_configuration(
config: &GenericConfiguration,
) -> Result<Self, GenericError>
pub fn from_configuration( config: &GenericConfiguration, ) -> Result<Self, GenericError>
Creates a new RemoteAgentClientConfiguration from the given configuration.
Errors
If the configuration is invalid, an error is returned.
Sourcepub fn auth(&self) -> &IpcAuthConfiguration
pub fn auth(&self) -> &IpcAuthConfiguration
Returns a reference to the authentication configuration for the Remote Agent client.
Sourcepub fn endpoint(&self) -> Result<Uri, GenericError>
pub fn endpoint(&self) -> Result<Uri, GenericError>
Returns the IPC endpoint URI.
If cmd_port is set, the endpoint is built from it, ignoring ipc_endpoint.
Sourcepub fn grpc_max_message_size(&self) -> usize
pub fn grpc_max_message_size(&self) -> usize
Returns the maximum message size for gRPC.