pub struct IpcAuthConfiguration { /* private fields */ }Expand description
Datadog Agent IPC authentication configuration.
Implementations
Sourceimpl IpcAuthConfiguration
impl IpcAuthConfiguration
Sourcepub fn from_configuration(
config: &GenericConfiguration,
) -> Result<Self, GenericError>
pub fn from_configuration( config: &GenericConfiguration, ) -> Result<Self, GenericError>
Errors
If the configuration is invalid, an error is returned.
Sourcepub fn auth_token_file_path(&self) -> PathBuf
pub fn auth_token_file_path(&self) -> PathBuf
Gets the path to the Agent authentication token file from the configuration.
Sourcepub fn ipc_cert_file_path(&self) -> PathBuf
pub fn ipc_cert_file_path(&self) -> PathBuf
Gets the IPC certificate file path from the configuration.